@@ -6,7 +6,6 @@ INTERPRETERS_ATTR = 'interpreters'
 
 
 CHOICES = [  # this should match the cookiecutter.json
-    # TODO Improvement: dynamically read from cookiecutter.json
     {'name': '3.6', 'checked': True},
     {'name': '3.7', 'checked': True},
     {'name': '3.8', 'checked': True},
@@ -27,6 +26,6 @@ def handle(choices: t.Optional[t.Sequence[str]] = None) -> t.Dict[str, t.Sequenc
     Returns:
         t.Sequence[str]: [description]
     """
-    return InteractiveDialog.create('interpreters-checkbox')(
+    return InteractiveDialog.create('interpreters-checkbox').dialog(
         [{'name': version, 'checked': True} for version in choices] if choices else CHOICES
     )
